IoDeviceError

Enum IoDeviceError 

pub enum IoDeviceError {
    Disconnected,
    BufferOverflow,
}
These are errors that an IoDevice may throw when it is requested to perform an operation.

Variants



Disconnected

This error needs to be thrown when the IoDevice has disconnected and can therefore no longer provide input.



BufferOverflow

This error indicates that the IoDevice has experienced an internal buffer overflow condition.